@@ -1,15 +1,15 @@
 import os
 import sys
 
-sys.path.append(os.path.abspath('.'))
-sys.path.append(os.path.abspath('..'))
-sys.path.append(os.path.abspath('../..'))
-sys.path.append(os.path.abspath('../../..'))
-sys.path.append(os.path.abspath('src'))
-sys.path.append(os.path.abspath('src/accelerated_graph_features'))
+# sys.path.append(os.path.abspath('.'))
+# sys.path.append(os.path.abspath('..'))
+# sys.path.append(os.path.abspath('../..'))
+# sys.path.append(os.path.abspath('../../..'))
+# sys.path.append(os.path.abspath('src'))
+# sys.path.append(os.path.abspath('src/accelerated_graph_features'))
 
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
-from features_algorithms.accelerated_graph_features.src import node_page_rank
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_algorithms.accelerated_graph_features.src import node_page_rank
 
 
 class PageRankCalculator(NodeFeatureCalculator):
