@@ -1,7 +1,7 @@
 import networkx as nx
 import numpy as np
 
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
 
 
 class AllPairsShortestPathCalculator(NodeFeatureCalculator):
